From The Interview to Iggy Azalea, 2014’s Worst Cultural Moments – Flavorwire
Author: http://flavorwire.com/author/sarah-seltzer
Description: Presenting; a mix of the morally execrable and the culturally annoying moments in 2014 that we sort wish had never happened, to be honest, although we dutifully thought and wrote about them (and to be even more honest, these ten moments are merely the tip-top of the Christmas tree of head-smacking m...
Keywords: celebrity, media, music, zzz-mailer-ready-feature, ariel pink, health goth, lena duham, renee zellweger, rude
Date: 2014-12-26T19:15:22+00:00

0

Media

## 13 Media Moments from 2014 We Could Have Lived Without

By Sarah Seltzer on Dec 26, 2014 2:15pm

Presenting; a mix of the morally execrable and the culturally annoying moments in 2014 that we sort wish had never happened, to be honest, although we dutifully thought and wrote about them (and to be even more honest, these ten moments are merely the tip-top of the Christmas tree of head-smacking moments from 2014.)

Adieu, 2014!

1. Celebrity nude photo leaks. It was a bummer when actresses were targeted by hackers who released their nude photos. And when everyone slut-shamed them as a result. Sidenote: same went for celebrity plastic surgery gawking.

2. Donald Sterling-gate. One of many examples of 2014 scandals that made us aware of how awfully racist people in power were, but this one was just the most epically depressing on a human level.

3. The Newsroom‘s Campus Rape Plotline and Aaron’s Sorkin’s response. Just no, Aaron Sorkin.

4. The Interview hacking brouhaha. Censorship is terrible and free speech is important, but why did we have to this discussion about a sub-par Rogen-Franco joint?

5. Igloo Australia’s Twitter racism. While pop star feuds, beefs, and rivalries are usually enjoyable and beneficial for everyone involved (I kid), Iggy Azalea’s ignorance on matters of race only reinforced her clueless pop persona.

6. Camille Cosby’s statement and Woody Allen’s letter to the New York Times. Alleged sexual predators and their wives: given a platform for victim-blaming since the beginning of modern media.

7. “Rude.” You are genuinely terrible, “Rude,” we declared this year. Also, you are still stuck in our heads and will inevitably be heard on New Year’s Eve.

8. Literary genre wars that weren’t. Did we really have to spend another year scolding each other for our reading choices? Even scolding the littlest readers?

9. Accusing Lena Dunham of a crime for her writing about of her sister on the left and right and trying to discredit her own sexual assault story on the right. Rape culture is serious, and the freedom some (white) artists have to be messy while other artists are constrained by social prejudice informs a lot of the understandable ire directed at Dunham. But none of those factors, nor anything Dunham has written, indicated she had committed a crime, nor that the assault she wrote about herself hadn’t taken place — and watching feminists and right-wingers join in on this one broke our hearts a little bit.

10. Normcore, Basic, and Health Goth. Stop trying to make fetch happen, bogus trend-pieces.

11. Ariel Pink. Was his misogyny a joke? A nasty slice of his real personality? Trolling because he realized he got more attention for being a jerk than for his music? To be real, much of this whole conversation was unnecessary.

12. This godawful, treacle-coated cover of Leonard Cohen’s “Hallelujah”.

13. The disrespectful, racist right wing media circus around Ferguson and the death of Michael Brown.

Bonus: Sarah Palin’s Christmas Pie-baking instruction and garbled speech special that’s eerily reminiscent of SNL’s “Martha Stewart’s Topless Christmas.” Just kidding, we’re so glad this happened! Never leave us, ex-governor Palin.

- ## Recent Features

- 13h

  And We're Back to 'Back to the Future Part II': Links You Need to See

- 14h

  Madonna, Can You Not?

- 15h

  What To Watch on TV: January 4-January 10

- 15h

  After Trans Teen Leelah Alcorn's Suicide, We All Must Do Better

- 17h

  Flavorwire’s Guide to Indie Flicks to See in January

- 17h

  The Confident 'Selfie' Finale Sets Up A Promising Future That We'll Never See

- 18h

  Ten Unique and Funky Literary Magazines To Check Out in 2015

- 19h

  Men of Honor, Vampires, Audiobooks, and 'Gilmore Girls': Highlights From Edward Herrmann's Career

- 20h

  The 5 Best Songs We Heard This Week: Kanye Inspired My First Cry of 2015

- 20h

  Subtly Beautiful Animated "Cinemagraphs" of the World Around Us

- ## Popular Posts

  View All Posts
- 22h

  The Best of Literary Criticism in 2014

- 3d

  The 10 Best Films and TV Shows About Disappearance

- 3d

  2014: The Death of the Postmodern Novel and the Rise of Autofiction

- 4d

  Flavorwire's Guide to (Expiring) Movies to Stream This New Year's Eve

- 4d

  Book Publishing Predictions for 2015

- View All Posts

Follow

### Follow “Flavorwire”

Get every new post delivered to your Inbox.

Join 8,750 other followers

Build a website with WordPress.com